@@ -3,12 +3,14 @@ import tensorflow as tf
 
 def allow_gpu_memory_growth(gpu_idx=0):
     """
-    Allowing GPU memory to grow as Tensorflow requires.
-    :param gpu_idx: Index number of the target GPU
-    :type gpu_idx: int
-    :return: None
-    :rtype: None
+    Allowing GPU memory growth as Tensorflow will reserve 100% memory space for GPU.
+
+    Args:
+        gpu_idx (int): Index number of the target GPU
+
+    Returns:
     """
+
     physical_devices = tf.config.list_physical_devices('GPU')
     try:
         tf.config.experimental.set_memory_growth(physical_devices[gpu_idx], True)
