@@ -238,7 +238,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
         """
         super(ModelSaverCallback, self).__init__()
         self.best_metric = best_metric
-        if self.best_metric == float('inf') and save_metric.find("accuracy") > 0:
+        if self.best_metric == float('inf') and metric_type == "score":
             self.best_metric = -self.best_metric
 
         self.epoch = epoch
@@ -494,7 +494,8 @@ def get_tf_callbacks(root,
         if not save_root:
             save_root = log_root_
         callbacks_.append(
-            ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric, file_name=save_file_name, metric_type=metric_type)
+            ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric,
+                               file_name=save_file_name, metric_type=metric_type)
         )
 
     if earlystop_callback:
